==> jangaroo-runtime-3.0.0.jar: META-INF/resources/amd/as3/joo/StandardClassLoader.js <==
define("as3/joo/StandardClassLoader",["module","exports","as3-rt/AS3","as3/joo/SystemClassLoader","as3/joo/loadClass","as3/joo/loadClasses"], function($module,$exports,AS3,SystemClassLoader,loadClass,loadClasses) { AS3.compilationUnit($module,$exports,function($primaryDeclaration){/*package joo {

/**
 * @deprecated use <code>joo.loadClasses()</code>.
 * @see joo.#loadClasses()
 * /
public class StandardClassLoader extends SystemClassLoader {

  private var imports:Array;

  /**
   * @deprecated use <code>joo.loadClasses()</code>.
   * @see joo.#loadClasses()
   * /
  public*/ function StandardClassLoader() {Super.call(this);
    this.imports$2 = [];
  }/*

  /**
   * @deprecated use <code>joo.loadClasses()</code>.
   * Import the class given by its fully qualified class name (package plus name).
   * All imports are collected in a hash and can be used in the #complete() callback function.
   * @param fullClassName : String the fully qualified class name (package plus name) of the class to load and import.
   * @see joo.#loadClasses()
   * /
  public*/ function import_(fullClassName/* : String*/)/* : void*/ {    
    this.imports$2.push(fullClassName);
  }/*

  /**
   * Run the static main method of a class given by its fully qualified name (package plus name), handing through the
   * given arguments (args).
   * The main method is executed after all classes are completed (see #complete()).
   * @param mainClassName : String the fully qualified name (package plus name) or the constructor function
   *   of the class to run.
   * @param args the arguments to hand over to the main method of the given class.
   * /
  public*/ function run(mainClassName/* : String, ...args*/)/* : void*/ {var args=Array.prototype.slice.call(arguments,1);
    loadClass(mainClassName, function joo$StandardClassLoader$39_30(mainClass/*:Class*/)/*:void*/ {
      mainClass["main"].apply(null, args);
    });
  }/*

  //noinspection JSMethodCanBeStatic
  /**
   * @deprecated
   * Explicitly initializing the static members of the given class (constructor function) is no longer
   * needed in Jangaroo 3.
   * @param classes the classes (type Function/Class) to initialize.
   * @return the last initialized class (constructor function). It only makes sense to use the return value
   *   if you use this method with exactly one parameter.
   * /
  override public*/ function init(/*... classes*/)/* : Function*/ {var classes=Array.prototype.slice.call(arguments);
    return classes[classes.length - 1];
  }/*

  /**
   * @deprecated use <code>joo.loadClasses()</code>.
   * Tell Jangaroo to load and initialize all required classes, then call the given function.
   * The function receives an import hash, which can be used in pure JavaScript in a 'with' statement
   * (Jangaroo does not support 'with', there, you would use import declarations!) like this:
   * <pre>
   * joo.classLoader.import_("com.custom.Foo");
   * joo.classLoader.complete(function(imports){with(imports){
   *   Foo.doSomething("bar");
   * }});
   * </pre>
   * @param onCompleteCallback : Function
   * @return void
   * @see joo.#loadClasses()
   * /
  public*/ function complete(onCompleteCallback/* : Function = undefined*/)/* : void*/ {
    var imports/*:Array*/ = this.imports$2;
    this.imports$2 = [];
    loadClasses(imports, function joo$StandardClassLoader$75_26()/*:void*/ {
      if (onCompleteCallback) {
        var importMap/*:Object*/ = {};
        for (var i/*:int*/ = 0; i < imports.length; i++) {
          var qName/*:String*/ = imports[i];
          var name/*:String*/ = qName.match(/[^.]+$/)[0];
          importMap[name] = arguments[i];
        }
        onCompleteCallback(importMap);
      }
    });
  }/*

}
}

============================================== Jangaroo part ==============================================*/
    var Super=SystemClassLoader._;
    var super$=Super.prototype;
    $primaryDeclaration(AS3.class_($module, {
      extends_: Super,
      members: {
        imports$2: {
          value: null,
          writable: true
        },
        constructor: StandardClassLoader,
        import_: import_,
        run: run,
        init: init,
        init$2: super$.init,
        complete: complete
      }
    }));
  });
});

==> jangaroo-runtime-3.0.1.jar: META-INF/resources/amd/as3/joo/StandardClassLoader.js <==
define("as3/joo/StandardClassLoader",["module","exports","as3-rt/AS3","as3/joo/SystemClassLoader","as3/joo/loadClass","as3/joo/loadClasses"], function($module,$exports,AS3,SystemClassLoader,loadClass,loadClasses) { AS3.compilationUnit($module,$exports,function($primaryDeclaration){/*package joo {

/**
 * @deprecated use <code>joo.loadClasses()</code>.
 * @see joo.#loadClasses()
 * /
public class StandardClassLoader extends SystemClassLoader {

  private var imports:Array;

  /**
   * @deprecated use <code>joo.loadClasses()</code>.
   * @see joo.#loadClasses()
   * /
  public*/ function StandardClassLoader() {Super.call(this);
    this.imports$2 = [];
  }/*

  /**
   * @deprecated use <code>joo.loadClasses()</code>.
   * Import the class given by its fully qualified class name (package plus name).
   * All imports are collected in a hash and can be used in the #complete() callback function.
   * @param fullClassName : String the fully qualified class name (package plus name) of the class to load and import.
   * @see joo.#loadClasses()
   * /
  public*/ function import_(fullClassName/* : String*/)/* : void*/ {    
    this.imports$2.push(fullClassName);
  }/*

  /**
   * Run the static main method of a class given by its fully qualified name (package plus name), handing through the
   * given arguments (args).
   * The main method is executed after all classes are completed (see #complete()).
   * @param mainClassName : String the fully qualified name (package plus name) or the constructor function
   *   of the class to run.
   * @param args the arguments to hand over to the main method of the given class.
   * /
  public*/ function run(mainClassName/* : String, ...args*/)/* : void*/ {var args=Array.prototype.slice.call(arguments,1);
    loadClass(mainClassName, function(mainClass/*:Class*/)/*:void*/ {
      mainClass["main"].apply(null, args);
    });
  }/*

  //noinspection JSMethodCanBeStatic
  /**
   * @deprecated
   * Explicitly initializing the static members of the given class (constructor function) is no longer
   * needed in Jangaroo 3.
   * @param classes the classes (type Function/Class) to initialize.
   * @return the last initialized class (constructor function). It only makes sense to use the return value
   *   if you use this method with exactly one parameter.
   * /
  override public*/ function init(/*... classes*/)/* : Function*/ {var classes=Array.prototype.slice.call(arguments);
    return classes[classes.length - 1];
  }/*

  /**
   * @deprecated use <code>joo.loadClasses()</code>.
   * Tell Jangaroo to load and initialize all required classes, then call the given function.
   * The function receives an import hash, which can be used in pure JavaScript in a 'with' statement
   * (Jangaroo does not support 'with', there, you would use import declarations!) like this:
   * <pre>
   * joo.classLoader.import_("com.custom.Foo");
   * joo.classLoader.complete(function(imports){with(imports){
   *   Foo.doSomething("bar");
   * }});
   * </pre>
   * @param onCompleteCallback : Function
   * @return void
   * @see joo.#loadClasses()
   * /
  public*/ function complete(onCompleteCallback/* : Function = undefined*/)/* : void*/ {
    var imports/*:Array*/ = this.imports$2;
    this.imports$2 = [];
    loadClasses(imports, function()/*:void*/ {
      if (onCompleteCallback) {
        var importMap/*:Object*/ = {};
        for (var i/*:int*/ = 0; i < imports.length; i++) {
          var qName/*:String*/ = imports[i];
          var name/*:String*/ = qName.match(/[^.]+$/)[0];
          importMap[name] = arguments[i];
        }
        onCompleteCallback(importMap);
      }
    });
  }/*

}
}

============================================== Jangaroo part ==============================================*/
    var Super=SystemClassLoader._;
    var super$=Super.prototype;
    $primaryDeclaration(AS3.class_($module, {
      extends_: Super,
      members: {
        imports$2: {
          value: null,
          writable: true
        },
        constructor: StandardClassLoader,
        import_: import_,
        run: run,
        init: init,
        init$2: super$.init,
        complete: complete
      }
    }));
  });
});
